==> history-issue-common-1.0.0-20220908.055630-9-sources.jar: cn/gtmap/realestate/supervise/entity/FzzRwxx.java <==
package cn.gtmap.realestate.supervise.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 非住宅任务信息表(FzzRwxx)实体类
 *
 * @author liujie
 * @since 2022-04-20 14:25:11
 */
@Table(name = "FZZ_RWXX")
public class FzzRwxx implements Serializable {
    private static final long serialVersionUID = -24413263513375171L;
    /**
     * 主键ID
     */
    @Id
    private String id;
    /**
     * 区划代码
     */
    private Object qhdm;
    /**
     * 区划名称
     */
    private String qhmc;
    /**
     * 项目名称
     */
    private String xmmc;
    /**
     * 化解责任人名称
     */
    private String hjzrrmc;
    /**
     * 化解责任人电话
     */
    private String hjzrrdh;
    /**
     * 不动产单元数
     */
    private Object bdcdys;
    /**
     * 实际建成时间
     */
    private String sjjcsj;
    /**
     * 其他问题说明

     */
    private Object qtwtsm;
    /**
     * 化解状态(0：未化解,1：已化解)
     */
    private Object hjzt;

    /**
     * 化解时间
     */
    private Date hjsj;

    /**
     * 创建时间
     */
    private Date cjsj;
    /**
     * 数据更新时间

     */
    private Date sjgxsj;


    private String col1;

    private String col2;

    private String col3;

    private String col4;

    private String col5;

    private String col6;

    private String col7;

    private String col8;


    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public Object getQhdm() {
        return qhdm;
    }

    public void setQhdm(Object qhdm) {
        this.qhdm = qhdm;
    }

    public String getQhmc() {
        return qhmc;
    }

    public void setQhmc(String qhmc) {
        this.qhmc = qhmc;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getHjzrrmc() {
        return hjzrrmc;
    }

    public void setHjzrrmc(String hjzrrmc) {
        this.hjzrrmc = hjzrrmc;
    }

    public String getHjzrrdh() {
        return hjzrrdh;
    }

    public void setHjzrrdh(String hjzrrdh) {
        this.hjzrrdh = hjzrrdh;
    }

    public Object getBdcdys() {
        return bdcdys;
    }

    public void setBdcdys(Object bdcdys) {
        this.bdcdys = bdcdys;
    }

    public String getSjjcsj() {
        return sjjcsj;
    }

    public void setSjjcsj(String sjjcsj) {
        this.sjjcsj = sjjcsj;
    }

    public Object getQtwtsm() {
        return qtwtsm;
    }

    public void setQtwtsm(Object qtwtsm) {
        this.qtwtsm = qtwtsm;
    }

    public Object getHjzt() {
        return hjzt;
    }

    public void setHjzt(Object hjzt) {
        this.hjzt = hjzt;
    }

    public Date getHjsj() {
        return hjsj;
    }

    public void setHjsj(Date hjsj) {
        this.hjsj = hjsj;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getCol1() {
        return col1;
    }

    public void setCol1(String col1) {
        this.col1 = col1;
    }

    public String getCol2() {
        return col2;
    }

    public void setCol2(String col2) {
        this.col2 = col2;
    }

    public String getCol3() {
        return col3;
    }

    public void setCol3(String col3) {
        this.col3 = col3;
    }

    public String getCol4() {
        return col4;
    }

    public void setCol4(String col4) {
        this.col4 = col4;
    }

    public String getCol5() {
        return col5;
    }

    public void setCol5(String col5) {
        this.col5 = col5;
    }

    public String getCol6() {
        return col6;
    }

    public void setCol6(String col6) {
        this.col6 = col6;
    }

    public String getCol7() {
        return col7;
    }

    public void setCol7(String col7) {
        this.col7 = col7;
    }

    public String getCol8() {
        return col8;
    }

    public void setCol8(String col8) {
        this.col8 = col8;
    }
}

==> history-issue-common-1.0.0-20231221.110741-11-sources.jar: cn/gtmap/realestate/supervise/entity/FzzRwxx.java <==
package cn.gtmap.realestate.supervise.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 非住宅任务信息表(FzzRwxx)实体类
 *
 * @author liujie
 * @since 2022-04-20 14:25:11
 */
@Table(name = "FZZ_RWXX")
public class FzzRwxx implements Serializable {
    private static final long serialVersionUID = -24413263513375171L;
    /**
     * 主键ID
     */
    @Id
    private String id;
    /**
     * 区划代码
     */
    private Object qhdm;
    /**
     * 区划名称
     */
    private String qhmc;
    /**
     * 项目名称
     */
    private String xmmc;
    /**
     * 化解责任人名称
     */
    private String hjzrrmc;
    /**
     * 化解责任人电话
     */
    private String hjzrrdh;
    /**
     * 不动产单元数
     */
    private Object bdcdys;
    /**
     * 实际建成时间
     */
    private String sjjcsj;
    /**
     * 附件名称
     */
    private String fjmc;
    /**
     * 附件地址
     */
    private String fjdz;
    /**
     * 其他问题说明
     */
    private Object qtwtsm;
    /**
     * 化解状态(0：未化解,1：已化解)
     */
    private Object hjzt;

    /**
     * 化解时间
     */
    private Date hjsj;

    /**
     * 创建时间
     */
    private Date cjsj;
    /**
     * 数据更新时间

     */
    private Date sjgxsj;


    private String col1;

    private String col2;

    private String col3;

    private String col4;

    private String col5;

    private String col6;

    private String col7;

    private String col8;


    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public Object getQhdm() {
        return qhdm;
    }

    public void setQhdm(Object qhdm) {
        this.qhdm = qhdm;
    }

    public String getQhmc() {
        return qhmc;
    }

    public void setQhmc(String qhmc) {
        this.qhmc = qhmc;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getHjzrrmc() {
        return hjzrrmc;
    }

    public void setHjzrrmc(String hjzrrmc) {
        this.hjzrrmc = hjzrrmc;
    }

    public String getHjzrrdh() {
        return hjzrrdh;
    }

    public void setHjzrrdh(String hjzrrdh) {
        this.hjzrrdh = hjzrrdh;
    }

    public Object getBdcdys() {
        return bdcdys;
    }

    public void setBdcdys(Object bdcdys) {
        this.bdcdys = bdcdys;
    }

    public String getSjjcsj() {
        return sjjcsj;
    }

    public void setSjjcsj(String sjjcsj) {
        this.sjjcsj = sjjcsj;
    }

    public Object getQtwtsm() {
        return qtwtsm;
    }

    public void setQtwtsm(Object qtwtsm) {
        this.qtwtsm = qtwtsm;
    }

    public Object getHjzt() {
        return hjzt;
    }

    public void setHjzt(Object hjzt) {
        this.hjzt = hjzt;
    }

    public Date getHjsj() {
        return hjsj;
    }

    public void setHjsj(Date hjsj) {
        this.hjsj = hjsj;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getCol1() {
        return col1;
    }

    public void setCol1(String col1) {
        this.col1 = col1;
    }

    public String getCol2() {
        return col2;
    }

    public void setCol2(String col2) {
        this.col2 = col2;
    }

    public String getCol3() {
        return col3;
    }

    public void setCol3(String col3) {
        this.col3 = col3;
    }

    public String getCol4() {
        return col4;
    }

    public void setCol4(String col4) {
        this.col4 = col4;
    }

    public String getCol5() {
        return col5;
    }

    public void setCol5(String col5) {
        this.col5 = col5;
    }

    public String getCol6() {
        return col6;
    }

    public void setCol6(String col6) {
        this.col6 = col6;
    }

    public String getCol7() {
        return col7;
    }

    public void setCol7(String col7) {
        this.col7 = col7;
    }

    public String getCol8() {
        return col8;
    }

    public void setCol8(String col8) {
        this.col8 = col8;
    }

    public String getFjmc() {
        return fjmc;
    }

    public void setFjmc(String fjmc) {
        this.fjmc = fjmc;
    }

    public String getFjdz() {
        return fjdz;
    }

    public void setFjdz(String fjdz) {
        this.fjdz = fjdz;
    }
}
